<?php
namespace FM\Controller;

use FM\Controller\FMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Libs\Util\NewCode;
use FM\Service\exemploService;

class exemploController extends FMCrud
{
    protected $dataSourceName = 'fct_relacescopomodelo_widget';
    protected $newCode;
    protected $exemploService;
   
    public function __construct($crudService, $environment, NewCode $newCode, exemploService $exemploService) {
        parent::__construct($crudService, $environment);
        $this->newCode = $newCode;
        $this->exemploService = $exemploService;
    }
    
    /**
     * A função "validaEscopoProposta" verifica se o escopo 
     * que está sendo relacionado já está relacionado ao modelo.
     */
    
    public function validaEscopoProposta(Request\Row $request, Response $response) {
    
        $row = $request->getRow();
        
        $tipoOrcamento = $row['NRTIPOORCAMENTO']; 
        $orcaModelo = $row['NRORCAMENTOMODELO'];
        
        $ValidaServEscopo = $this->exemploService->validaEscopoProposta($tipoOrcamento, $orcaModelo);
        
        $dtsValServEscopo = new DataSet('VALIDAESCOPO', array('VALIDA'=>$ValidaServEscopo));
        
        $response->addDataSet($dtsValServEscopo);
    
    } 
    
    public function saveInsert(Request $request, Response $response) {
        
        $rows = $request->getDataSet()->getRows();
        
        foreach($rows as $row) {
            $row['NRRELACESCOPOMODELO'] = $this->newCode->getCodeByTableName("FCT_RELACESCOPOMODELO", $this->environment->getNrOrg());
        }
        
        $request->setParameter('dbname', 'fct_relacescopomodelo_widget');
        parent::save($request, $response);
        
    }
    
    public function save(Request $request, Response $response) {
        
        $request->setParameter('dbname', 'fct_relacescopomodelo_widget');
        parent::save($request, $response);
        
    }
    
    public function find(Request\Filter $request, Response $response) {
    
        $request->setParameter('dbname', 'fct_relacescopomodelo_widget');
        parent::find($request, $response);
    
    }
    
    public function delete(Request $request, Response $response) {
    
        $request->setParameter('dbname', 'fct_relacescopomodelo_widget');
        parent::delete($request, $response);
    
    }
    /**
     * Salva a edição dos documentos ligados a um escopo
    ***/
    public function editarDocumentosEscopoModelo(Request\Row $request, Response $response){
        try {
            $row        = $request->getRow();
            $nrorg      = $this->environment->getNrorg();
            $cdoperador = $this->environment->getCdOperador();
            if(!$row["__is_new"]) {
                $this->exemploService->editarDocumentosEscopoModelo($row, $nrorg, $cdoperador);
            } else {
                $request->setParameter('dbname', 'fct_orcaescopodoc');
                $row["NRORCAESCOPODOC"] = $this->newCode->getCodeByTableName("FCT_ORCAESCOPODOC", $nrorg, 1, 10, true);
                parent::save($request, $response);
            }
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * retorna quais das situações selecionadas já estão inseridas na tabela
    ***/
    public function validarExistenciaIdsituacao(Request\Row $request, Response $response){
        try {
            $row    = $request->getRow();
            $nrorg  = $this->environment->getNrorg();
            $this->exemploService->validarExistenciaIdsituacao($row, $nrorg);
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Deleta modelos de documentos vinculado ao escopo
    **/
    public function deletarDocumentos(Request $request, Response $response) {
        try {
            $row = $request->getDataSet()->getRows()[0];
            $nrorcadocs = explode(", ", $row["NRORCAESCOPODOC"]);
            $request->setParameter('dbname', 'fct_orcaescopodoc');
            foreach($nrorcadocs as $nrorcadoc) {
                $row["NRORCAESCOPODOC"] = $nrorcadoc;
                parent::delete($request, $response);
            }
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * insere os signatários padrões de modelo de proposta que foram buscados na parametrização SM 
    **/
    public function insereSignatariosPadroesOrca(Request\Row $request, Response $response){
        try {
            $row      = $request->getRow();
            $nrorg    = $this->environment->getNrorg();
            $operador = $this->environment->getCdOperador();
            
            $this->exemploService->insereSignatariosPadroesOrca($row, $nrorg, $operador);
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
     /**
     * A função "cadAutoSignatPadrOrca" realiza o cadastramento automático dos signatários padrões do modelo de proposta
     */
    public function cadAutoSignatPadrOrca(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            
            $result = $this->exemploService->cadAutoSignatPadrOrca($row);
            $response->addDataSet(new DataSet("cadauto", array("retorno" => $result)));

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * A função "validaSignatPadrOrca" realiza a validação dos signatários padrões para evitar a inclusão repetida de um parceiro.
     */
    public function validaSignatPadrOrca(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            
            $result = $this->exemploService->validaSignatPadrOrca($row);
            $response->addDataSet(new DataSet("validaSignatPadrOrca", array("valida" => $result)));

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Valida se o token da certsign está preenchido
     */
    public function validaIdCertsign(Request\Row $request, Response $response){
        try {
            $nrorg = $this->environment->getNrorg();
            
            $result = $this->exemploService->validaIdCertsign($nrorg);
            $response->addDataSet(new DataSet("validaIdCertsign", array("retorno" => $result)));
            
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * A função "insereOperadoresNotifica" realiza a inserção dos operadores do sistema que devem ser notificados.
     */
    public function insereOperadoresNotifica(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            
            $nrsignatpadrorca = $row["NRSIGNATPADRORCA"];
            $operadores = $row["OPERADORES"];
            
            $this->exemploService->insereOperadoresNotifica($nrsignatpadrorca, $operadores);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}
?>